module.exports={A:{A:{"2":"K D E F rC","8":"A B"},B:{"1":"Q","2":"0 H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I","8":"C L M G N O P"},C:{"2":"0 1 2 3 sC PC J UB K D E F A B C L M G N O P VB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC vC wC","66":"4 5 6 7 8 9 WB","72":"XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB"},D:{"1":"aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q","2":"0 1 2 3 4 5 6 7 J UB K D E F A B C L M G N O P VB H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","66":"8 9 WB XB YB ZB"},E:{"2":"J UB xC VC yC","8":"K D E F A B C L M G zC 0C 1C WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C"},F:{"1":"1 2 3 4 5 6 7 8 9 WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B","2":"0 F B C 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z 9C AD BD CD JC pC DD KC","66":"G N O P VB"},G:{"2":"VC ED qC FD GD","8":"E HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC"},H:{"2":"bD"},I:{"1":"hD","2":"PC J I cD dD eD fD qC gD"},J:{"2":"D A"},K:{"2":"A B C H JC pC KC"},L:{"2":"I"},M:{"2":"IC"},N:{"2":"A B"},O:{"1":"LC"},P:{"1":"J iD jD kD lD mD WC nD oD","2":"1 2 3 4 5 6 7 8 9 pD qD rD MC NC OC sD"},Q:{"1":"tD"},R:{"2":"uD"},S:{"2":"wD","72":"vD"}},B:7,C:"Custom Elements (deprecated V0 spec)",D:true};
