module.exports={A:{A:{"2":"F A B rC","8":"K D E"},B:{"2":"C L M G N O P","8":"Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC","129":"sC PC vC wC"},D:{"1":"5","8":"1 2 3 4 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC"},E:{"1":"A B C L M G WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","260":"J UB K D E F xC VC yC zC 0C 1C"},F:{"2":"F","8":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC","584":"S T U V W X Y Z a b c d","1025":"0 e f g h i j k l m n o p q r s t u v w x y z","2052":"B C 9C AD BD CD JC pC DD KC"},G:{"1":"E FD GD HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC","8":"VC ED qC"},H:{"8":"bD"},I:{"8":"PC J cD dD eD fD qC gD hD","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C JC pC KC","1025":"H"},L:{"1025":"I"},M:{"1":"IC"},N:{"2":"A B"},O:{"8":"LC"},P:{"1":"2 3 4 5 6 7 8 9","8":"1 J iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"8":"tD"},R:{"8":"uD"},S:{"1":"vD wD"}},B:2,C:"MathML",D:true};
