module.exports={A:{A:{"2":"K D E rC","260":"F A B"},B:{"2":"TB I","66":"JB KB LB MB NB OB PB QB RB SB","132":"0 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB","260":"C L M G N O P"},C:{"2":"sC PC J UB IC UC tC uC vC wC","260":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC"},D:{"2":"RB SB TB I TC IC UC","16":"J UB K D E F A B C L M","66":"JB KB LB MB NB OB PB QB","132":"0 1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB"},E:{"2":"oC 8C","16":"xC VC","132":"J UB K D E F A B C L M G yC zC 0C 1C WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC"},F:{"1":"C DD KC","2":"F 9C AD BD CD","16":"B JC pC","66":"0 w x y z","132":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v"},G:{"2":"oC","16":"VC ED","132":"E qC FD GD HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC"},H:{"2":"bD"},I:{"2":"I","16":"cD dD","132":"PC J eD fD qC gD hD"},J:{"132":"D A"},K:{"1":"C KC","2":"A","16":"B JC pC","132":"H"},L:{"2":"I"},M:{"2":"IC"},N:{"260":"A B"},O:{"132":"LC"},P:{"132":"1 2 3 4 5 6 7 8 9 J iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"132":"tD"},R:{"132":"uD"},S:{"260":"vD wD"}},B:7,C:"Mutation events",D:true};
