module.exports={A:{A:{"2436":"K D E F A B rC"},B:{"260":"O P","2436":"C L M G N","8196":"0 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"2":"1 2 sC PC J UB K D E F A B C L M G N O P VB vC wC","772":"3 4 5 6 7 8 9 WB XB YB ZB aB bB cB dB eB fB gB hB","4100":"0 iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC"},D:{"2":"J UB K D E F A B C","2564":"1 2 3 4 5 6 7 8 9 L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB","8196":"0 zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","10244":"kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB"},E:{"1":"C L M G KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","16":"xC VC","2308":"A B WC JC","2820":"J UB K D E F yC zC 0C 1C"},F:{"2":"F B 9C AD BD CD JC pC DD","16":"C","516":"KC","2564":"1 2 3 4 5 6 7 8 9 G N O P VB WB","8196":"0 mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","10244":"XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB"},G:{"1":"PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC","2":"VC ED qC","2820":"E FD GD HD ID JD KD LD MD ND OD"},H:{"2":"bD"},I:{"2":"PC J cD dD eD fD qC","260":"I","2308":"gD hD"},J:{"2":"D","2308":"A"},K:{"2":"A B C JC pC","16":"KC","8196":"H"},L:{"8196":"I"},M:{"1028":"IC"},N:{"2":"A B"},O:{"8196":"LC"},P:{"2052":"iD jD","2308":"J","8196":"1 2 3 4 5 6 7 8 9 kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"8196":"tD"},R:{"8196":"uD"},S:{"4100":"vD wD"}},B:5,C:"Synchronous Clipboard API",D:true};
