module.exports={A:{A:{"2":"K D E rC","2561":"A B","2692":"F"},B:{"1":"0 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I","2561":"C L M G N O P"},C:{"1":"0 qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC","16":"sC","1537":"1 2 3 4 5 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB wC","1796":"PC vC"},D:{"1":"0 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","16":"J UB K D E F A B C L M","1025":"cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B","1537":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB"},E:{"1":"M G 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","16":"J UB K xC VC","1025":"D E F A B C zC 0C 1C WC JC","1537":"yC","4097":"L KC"},F:{"1":"0 tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z KC","16":"F B C 9C AD BD CD JC pC","260":"DD","1025":"3 4 5 6 7 8 9 WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB","1537":"1 2 G N O P VB"},G:{"1":"SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC","16":"VC ED qC","1025":"E ID JD KD LD MD ND OD PD","1537":"FD GD HD","4097":"QD RD"},H:{"2":"bD"},I:{"16":"cD dD","1025":"I hD","1537":"PC J eD fD qC gD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H JC pC KC"},L:{"1":"I"},M:{"1":"IC"},N:{"2561":"A B"},O:{"1":"LC"},P:{"1025":"1 2 3 4 5 6 7 8 9 J iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"1":"tD"},R:{"1":"uD"},S:{"1":"wD","1537":"vD"}},B:1,C:"input event",D:true};
