module.exports={A:{A:{"388":"A B","900":"K D E F rC"},B:{"388":"C L M G N O P","641":"0 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I","900":"Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},C:{"772":"0 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC","900":"1 2 3 4 5 6 7 8 9 sC PC J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B vC wC"},D:{"641":"0 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","900":"1 2 3 4 5 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},E:{"772":"A","900":"J UB K D E F B C L M G xC VC yC zC 0C 1C WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C"},F:{"16":"F 9C","129":"B C AD BD CD JC pC DD KC","641":"0 d e f g h i j k l m n o p q r s t u v w x y z","900":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c"},G:{"900":"E VC ED qC FD GD HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC"},H:{"129":"bD"},I:{"641":"I","900":"PC J cD dD eD fD qC gD hD"},J:{"900":"D A"},K:{"129":"A B C JC pC KC","641":"H"},L:{"900":"I"},M:{"772":"IC"},N:{"388":"A B"},O:{"900":"LC"},P:{"641":"2 3 4 5 6 7 8 9","900":"1 J iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"900":"tD"},R:{"900":"uD"},S:{"772":"wD","900":"vD"}},B:2,C:"CSS page-break properties",D:true};
