module.exports={A:{A:{"1":"A B","2":"K D E F rC"},B:{"1":"C L M G N O P","516":"0 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"132":"tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B","164":"1 2 3 4 5 6 7 8 9 sC PC J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB vC wC","516":"4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a","1028":"0 b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC"},D:{"420":"1 2 3 4 5 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB","516":"0 rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC"},E:{"1":"A B C L M G WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","132":"F 1C","164":"D E 0C","420":"J UB K xC VC yC zC"},F:{"1":"C JC pC DD KC","2":"F B 9C AD BD CD","420":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB","516":"0 eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC","132":"JD KD","164":"E HD ID","420":"VC ED qC FD GD"},H:{"1":"bD"},I:{"420":"PC J cD dD eD fD qC gD hD","516":"I"},J:{"420":"D A"},K:{"1":"C JC pC KC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"IC"},N:{"1":"A B"},O:{"516":"LC"},P:{"420":"J","516":"1 2 3 4 5 6 7 8 9 iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"516":"tD"},R:{"516":"uD"},S:{"164":"vD wD"}},B:4,C:"CSS3 Multiple column layout",D:true};
