module.exports={A:{A:{"1":"B","4":"K D E F A rC"},B:{"1":"C L M G N","129":"0 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"1":"1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB","4":"sC PC J UB vC wC","129":"0 sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC"},D:{"1":"mB nB oB pB qB rB sB tB uB vB","4":"J UB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC"},E:{"4":"J UB xC VC","129":"K D E F A B C L M G yC zC 0C 1C WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C"},F:{"1":"C ZB aB bB cB dB eB fB gB hB iB JC pC DD KC","4":"F B 9C AD BD CD","129":"0 1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"4":"VC ED qC","129":"E FD GD HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC"},H:{"4":"bD"},I:{"4":"cD dD eD","129":"PC J I fD qC gD hD"},J:{"129":"D A"},K:{"1":"C JC pC KC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"IC"},N:{"1":"B","4":"A"},O:{"129":"LC"},P:{"129":"1 2 3 4 5 6 7 8 9 J iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"129":"tD"},R:{"129":"uD"},S:{"1":"vD","129":"wD"}},B:1,C:"dataset & data-* attributes",D:true};
