module.exports={A:{A:{"1":"B","2":"K D E F rC","164":"A"},B:{"1":"0 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"1":"0 QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC","2":"sC PC J UB vC wC","8":"1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB","328":"iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB"},D:{"1":"0 wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","2":"1 2 J UB K D E F A B C L M G N O P VB","8":"3 4 5 6 7 8 9 WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB","584":"tB uB vB"},E:{"1":"L M G 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","2":"J UB K xC VC yC","8":"D E F A B C zC 0C 1C WC JC","1096":"KC"},F:{"1":"0 jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C 9C AD BD CD JC pC DD KC","8":"1 2 3 4 5 6 7 8 9 G N O P VB WB XB YB ZB aB bB cB dB eB fB","584":"gB hB iB"},G:{"1":"SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC","8":"E VC ED qC FD GD HD ID JD KD LD MD ND OD PD QD","6148":"RD"},H:{"2":"bD"},I:{"1":"I","8":"PC J cD dD eD fD qC gD hD"},J:{"8":"D A"},K:{"1":"H","2":"A","8":"B C JC pC KC"},L:{"1":"I"},M:{"1":"IC"},N:{"1":"B","36":"A"},O:{"1":"LC"},P:{"1":"1 2 3 4 5 6 7 8 9 jD kD lD mD WC nD oD pD qD rD MC NC OC sD","2":"iD","8":"J"},Q:{"1":"tD"},R:{"1":"uD"},S:{"1":"wD","328":"vD"}},B:2,C:"Pointer events",D:true};
