module.exports={A:{A:{"2":"F A B rC","8":"K D E"},B:{"2":"0 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I"},C:{"2":"0 1 2 3 4 5 6 7 8 9 sC PC J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC tC uC vC wC"},D:{"1":"1 2 3 4 5 6 7 8 9 J UB K D E F A B C L M G N O P VB WB XB YB ZB aB bB cB dB eB","2":"0 sB tB uB vB wB xB yB zB QC 0B RC 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB I TC IC UC","130":"fB gB hB iB jB kB lB mB nB oB pB qB rB"},E:{"1":"J UB K D E F A B C L M G VC yC zC 0C 1C WC JC KC 2C 3C 4C XC YC LC 5C MC ZC aC bC cC dC 6C NC eC fC gC hC iC 7C OC jC kC lC mC nC oC 8C","2":"xC"},F:{"1":"1 2 3 4 5 F B C G N O P VB 9C AD BD CD JC pC DD KC","2":"0 eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC Q H R SC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","130":"6 7 8 9 WB XB YB ZB aB bB cB dB"},G:{"1":"E VC ED qC FD GD HD ID JD KD LD MD ND OD PD QD RD SD TD UD VD WD XD XC YC LC YD MC ZC aC bC cC dC ZD NC eC fC gC hC iC aD OC jC kC lC mC nC oC"},H:{"258":"bD"},I:{"1":"PC J fD qC gD hD","2":"I cD dD eD"},J:{"1":"D A"},K:{"1":"A B C JC pC KC","2":"H"},L:{"130":"I"},M:{"2":"IC"},N:{"2":"A B"},O:{"2":"LC"},P:{"1":"J","130":"1 2 3 4 5 6 7 8 9 iD jD kD lD mD WC nD oD pD qD rD MC NC OC sD"},Q:{"2":"tD"},R:{"130":"uD"},S:{"2":"vD wD"}},B:2,C:"SVG fonts",D:true};
